<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://devrohit.com/
 * @since      1.1.0
 *
 * @package    Dr_Affilate
 * @subpackage Dr_Affilate/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.1.0
 * @package    Dr_Affilate
 * @subpackage Dr_Affilate/includes
 * @author     Rohit Urane <rohiturane50@gmail.com>
 */
class Dr_Affilate {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.1.0
	 * @access   protected
	 * @var      Dr_Affilate_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.1.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.1.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.1.0
	 */
	public function __construct() {
		if ( defined( 'DR_AFFILATE_VERSION' ) ) {
			$this->version = DR_AFFILATE_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'dr-affilate';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Dr_Affilate_Loader. Orchestrates the hooks of the plugin.
	 * - Dr_Affilate_i18n. Defines internationalization functionality.
	 * - Dr_Affilate_Admin. Defines all hooks for the admin area.
	 * - Dr_Affilate_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.1.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-dr-affilate-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-dr-affilate-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-dr-affilate-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-dr-affilate-public.php';

		$this->loader = new Dr_Affilate_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Dr_Affilate_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.1.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Dr_Affilate_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.1.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Dr_Affilate_Admin( $this->get_plugin_name(), $this->get_version() );
		//load all the script and style
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		//add menu to admin panel
		$this->loader->add_action( 'admin_menu', $plugin_admin, 'add_plugin_admin_menu' );
		$this->loader->add_action('enqueue_block_editor_assets', $plugin_admin, 'equeue_editor_asset');
		$this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_image_asset');
		/// Review from customers
		$this->loader->add_action('admin_notices', $plugin_admin, 'get_review_from_customer');
		// Save/Update our plugin options
		$this->loader->add_action('admin_init', $plugin_admin, 'options_update');
		$this->loader->add_action( 'wp_ajax_get_data', $plugin_admin,'get_affiliate_link' );
		$this->loader->add_action( 'wp_ajax_get_data_image', $plugin_admin,'get_affiliate_images' );
		$this->loader->add_action( 'wp_ajax_get_data_specific_image',$plugin_admin,'get_data_specific_image');
		$this->loader->add_action( 'wp_ajax_done_review', $plugin_admin,'update_review_flag' );
		// CRUD Opeartion of Affiliate Link
		$this->loader->add_action( 'admin_post_dr_affiliate_store',$plugin_admin, 'dr_affiliate_save');
		$this->loader->add_action( 'admin_post_dr_affiliate_update',$plugin_admin, 'dr_affiliate_update');
		$this->loader->add_action( 'admin_get_dr_affiliate_delete',$plugin_admin, 'dr_affiliate_delete');
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.1.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Dr_Affilate_Public( $this->get_plugin_name(), $this->get_version() );
		// Load all script and style
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action("wp_ajax_track_links", $plugin_public,'track_affiliate_link');
		$this->loader->add_action("wp_ajax_nopriv_track_links", $plugin_public,'track_affiliate_link');
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.1.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.1.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.1.0
	 * @return    Dr_Affilate_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.1.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}
